searchData={"items":[{"type":"module","title":"Knet","doc":"Documentation for `Knet`.","ref":"Knet.html"},{"type":"function","title":"Knet.get_payment_link/1","doc":"Takes a map of payment details and returns a KNET payment link.\n\nThe `payment_details` map should contain the following required keys:\n- `knet_username`\n- `knet_password`\n- `knet_key`\n- `amount`\n- `response_url`\n- `error_url`\n- `track_id`\n\n\nThe following keys are optional:\n- `knet_url` (defaults to https://kpay.com.kw/kpg/PaymentHTTP.htm)\n- `currency_code` (defaults to 414)\n- `lang`. Could be ENG or AR (defaults to ENG)\n- `udf1` to `udf10` (user defined fields). These are optional and will be returned back to you in the response.\n\nExample:\n\n```\npayment_details = %{\n  \"knet_username\" => \"your-knet-api-username-or-id\",\n  \"knet_password\" => \"your-knet-api-password\",\n  \"knet_key\" => \"your-knet-api-key\",\n  \"track_id\" => \"230814Kdiu83fkjdsl\",\n  \"amount\" => \"1.5\",\n  \"response_url\" => \"http://localhost:4000/\",\n  \"error_url\" => \"http://localhost:4000/\"\n  \"lang\" => \"ENG\",\n  \"udf1\" => \"my custom value\"\n}\n\nKnet.get_payment_link(payment_details)\n#=> \"https://kpay.com.kw/kpg/PaymentHTTP.htm?param=paymentInit&trandata=73425fd4...7be9cea92&responseURL=http://localhost:8001/&errorURL=http://localhost:8001/\"\n```","ref":"Knet.html#get_payment_link/1"},{"type":"function","title":"Knet.get_transaction_details/1","doc":"Takes a map of transaction details and returns the transaction details from KNET.\n\nYou might want to use this function to verify the status of a transaction.\n\nThe `params` map should contain the following required keys:\n- `knet_username`\n- `knet_password`\n- `track_id` (the same `track_id` used in the payment link)\n- `amount`\n\n\nThe following keys are optional:\n- `knet_url` (defaults to https://kpay.com.kw/kpg/tranPipe.htm?param=tranInit)\n- `trans_id` (defaults to the `track_id` value)\n- `udf5` (defaults to \"TrackID\")\n\n\nThis function returns:\n- `{:ok, map()}` if the transaction details were fetched successfully.\n- `{:error, map()}` if the transaction details could not be obtained successfully.\n\n\nExample of a successful attempt to retrieve an existing transaction:\n\n```\n{:ok,\n %{\n   \"amt\" => \"9.500\",\n   \"auth\" => \"887766\",\n   \"authRespCode\" => \"00\",\n   \"avr\" => \"N\",\n   \"payid\" => \"123456789\",\n   \"postdate\" => \"0814\",\n   \"ref\" => \"35666353638\",\n   \"result\" => \"SUCCESS\",\n   \"trackid\" => \"23098372989272\",\n   \"tranid\" => \"328276498379404\",\n   \"udf1\" => \"some-value\",\n   \"udf2\" => \"\",\n   \"udf3\" => nil,\n   \"udf4\" => nil,\n   \"udf5\" => \"TrackID\",\n   \"udf6\" => nil,\n   \"udf7\" => nil,\n   \"udf8\" => nil,\n   \"udf9\" => nil,\n   \"udf10\" => nil\n }}\n```\n\n\nExample of a failed attempt to retrieve a non-existent transaction:\n\n```\n{:error,\n %{\n   \"error_code_tag\" => \"IPAY0100263\",\n   \"error_service_tag\" => \"null\",\n   \"result\" => \"!ERROR!-IPAY0100263-Transaction not found.\"\n }}\n```","ref":"Knet.html#get_transaction_details/1"},{"type":"function","title":"Knet.parse_payment_response/1","doc":"Takes a map of encrypted payment response details and returns the decrypted details.\n\nThe `params` map should contain the following required keys:\n- `knet_key`\n- `trandata` (the encrypted response data received from KNET)\n\nExample:\n\n```\nparams = %{\n  \"knet_key\" => \"your-knet-api-key\",\n  \"trandata\" => \"A7241C57D2BBA5D16...4C8270500555B829F760EEC53\"\n}\nKnet.parse_payment_response(params)\n{:ok,\n  %{\n    \"amt\" => \"1.500\",\n    \"auth\" => \"000000\",\n    \"authRespCode\" => \"55\",\n    \"avr\" => \"N\",\n    \"paymentid\" => \"103322640000108419\",\n    \"postdate\" => \"0814\",\n    \"ref\" => \"322644009696\",\n    \"result\" => \"NOT CAPTURED\",\n    \"trackid\" => \"230815jfldshguifdsh\",\n    \"tranid\" => \"322638003291215\",\n    \"udf1\" => \"\",\n    \"udf2\" => \"\",\n    \"udf3\" => \"\",\n    \"udf4\" => \"\",\n    \"udf5\" => \"\",\n    \"udf6\" => \"\",\n    \"udf7\" => \"\",\n    \"udf8\" => \"\",\n    \"udf9\" => \"\",\n    \"udf10\" => \"\",\n  }\n}\n```","ref":"Knet.html#parse_payment_response/1"}],"content_type":"text/markdown"}